BREP
A boundary representation (BREP) geometry kernel for building CAD applications.
The project is intended to provide core CAD functionality including topology, geometry, solid modeling, modeling operations, and visualization.
Status
BREP is currently in early development. APIs are expected to change substantially before reaching a stable release.
Constants
- EARLY_
DEVELOPMENT - Indicates that this is an early-development release of the BREP kernel.
Functions
- version
- Returns the current BREP package version.